summaryrefslogtreecommitdiff
path: root/lib/tdb2/test/run-tdb1-readonly-check.c
diff options
context:
space:
mode:
authorRusty Russell <rusty@rustcorp.com.au>2011-09-14 07:59:13 +0930
committerRusty Russell <rusty@rustcorp.com.au>2011-09-14 07:59:13 +0930
commit8e14a3e06d42b0302868dc3911a2e607e42a51b3 (patch)
treeada1f4891472e6a4d3904327fb7f6bc0264f915c /lib/tdb2/test/run-tdb1-readonly-check.c
parent5d9dd8d541a761e0af2c8d50ee55485f2cef3e01 (diff)
downloadsamba-8e14a3e06d42b0302868dc3911a2e607e42a51b3.tar.gz
samba-8e14a3e06d42b0302868dc3911a2e607e42a51b3.tar.bz2
samba-8e14a3e06d42b0302868dc3911a2e607e42a51b3.zip
tdb2: unify tdb1_check and tdb1_summary into tdb_check and tdb_summary.
Switch on the TDB_VERSION1 flag. Also, change tdb1_check's checkfn argument to return an error code (and set tdb->last_error accordingly). Signed-off-by: Rusty Russell <rusty@rustcorp.com.au> (Imported from CCAN commit ef92843f2c74ab9d4fa7f167a2182e5e8955df91)
Diffstat (limited to 'lib/tdb2/test/run-tdb1-readonly-check.c')
-rw-r--r--lib/tdb2/test/run-tdb1-readonly-check.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/tdb2/test/run-tdb1-readonly-check.c b/lib/tdb2/test/run-tdb1-readonly-check.c
index 471f813da2..f42a8f5e27 100644
--- a/lib/tdb2/test/run-tdb1-readonly-check.c
+++ b/lib/tdb2/test/run-tdb1-readonly-check.c
@@ -1,5 +1,5 @@
/* We should be able to tdb1_check a O_RDONLY tdb, and we were previously allowed
* to tdb1_check() inside a transaction (though that's paranoia!). */
#include "tdb2-source.h"
#include <ccan/tap/tap.h>
#include <stdlib.h>
@@ -28,11 +28,11 @@ int main(int argc, char *argv[])
data.dptr = (void *)"world";
ok1(tdb_store(tdb, key, data, TDB_INSERT) == TDB_SUCCESS);
- ok1(tdb1_check(tdb, NULL, NULL) == 0);
+ ok1(tdb_check(tdb, NULL, NULL) == TDB_SUCCESS);
/* We are also allowed to do a check inside a transaction. */
ok1(tdb_transaction_start(tdb) == TDB_SUCCESS);
- ok1(tdb1_check(tdb, NULL, NULL) == 0);
+ ok1(tdb_check(tdb, NULL, NULL) == TDB_SUCCESS);
ok1(tdb_close(tdb) == 0);
tdb = tdb_open("run-readonly-check.tdb1",
@@ -40,7 +40,7 @@ int main(int argc, char *argv[])
ok1(tdb);
ok1(tdb_store(tdb, key, data, TDB_MODIFY) == TDB_ERR_RDONLY);
- ok1(tdb1_check(tdb, NULL, NULL) == 0);
+ ok1(tdb_check(tdb, NULL, NULL) == TDB_SUCCESS);
ok1(tdb_close(tdb) == 0);
return exit_status();
@@ -1,5 +1,5 @@
-/* We should be able to tdb1_check a O_RDONLY tdb, and we were previously allowed
- * to tdb1_check() inside a transaction (though that's paranoia!). */
+/* We should be able to tdb_check a O_RDONLY tdb, and we were previously allowed
+ * to tdb_check() inside a transaction (though that's paranoia!). */
#include "tdb2-source.h"
#include <ccan/tap/tap.h>